# OASIS4 Interface para DJANGO

Este paquete contiene un conjunto de modelos y managers que permiten el acceso a las tablas de OASIS4 desde el aplicativo DJANGO y las expone como objetos
para los restantes módulos.

